@@ -163,13 +163,10 @@ gtk_plot_box_get_property (GObject      *object,
 static void
 gtk_plot_box_init (GtkPlotBox *dataset)
 {
-  GdkColor black, white;
-  GdkColormap *colormap;
+  GdkRGBA black, white;
 
-  colormap = gdk_colormap_get_system();
-
-  gdk_color_black(colormap, &black);
-  gdk_color_white(colormap, &white);
+  gdk_rgba_parse(&black, "black");
+  gdk_rgba_parse(&white, "white");
 
   GTK_PLOT_DATA(dataset)->symbol.symbol_style = GTK_PLOT_SYMBOL_FILLED;
   GTK_PLOT_DATA(dataset)->symbol.color = white;
