@@ -47,7 +47,7 @@ enum {
                                                                                 
 static void gtk_plot_pixmap_class_init 		(GtkPlotPixmapClass *klass);
 static void gtk_plot_pixmap_init 		(GtkPlotPixmap *data);
-static void gtk_plot_pixmap_destroy             (GtkObject *object);
+static void gtk_plot_pixmap_destroy             (GtkWidget *object);
 static void gtk_plot_pixmap_draw_symbol		(GtkPlotData *data,
                                                  gdouble x, 
                                                  gdouble y, 
@@ -100,13 +100,13 @@ gtk_plot_pixmap_get_type (void)
 static void
 gtk_plot_pixmap_class_init (GtkPlotPixmapClass *klass)
 {
-  GtkObjectClass *object_class;
+  GtkWidgetClass *object_class;
   GtkPlotDataClass *data_class;
   GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
 
   parent_class = g_type_class_ref (gtk_plot_data_get_type ());
 
-  object_class = (GtkObjectClass *) klass;
+  object_class = (GtkWidgetClass *) klass;
   data_class = (GtkPlotDataClass *) klass;
 
   data_class->clone = gtk_plot_pixmap_clone;
@@ -162,14 +162,14 @@ gtk_plot_pixmap_set_property (GObject      *object,
                                                                                 
   switch(prop_id){
     case ARG_PIXMAP:
-      if(pixmap->pixmap) gdk_pixmap_unref(pixmap->pixmap);
-      pixmap->pixmap = (GdkPixmap *)g_value_get_pointer(value);
-      if(pixmap->pixmap) gdk_pixmap_ref(pixmap->pixmap);
+      if(pixmap->pixmap) cairo_surface_destroy(pixmap->pixmap);
+      pixmap->pixmap = (cairo_surface_t *)g_value_get_pointer(value);
+      if(pixmap->pixmap) cairo_surface_reference(pixmap->pixmap);
       break;
     case ARG_MASK:
-      if(pixmap->mask) gdk_bitmap_unref(pixmap->mask);
-      pixmap->mask = (GdkBitmap *)g_value_get_pointer(value);
-      if(pixmap->mask) gdk_bitmap_ref(pixmap->mask);
+      if(pixmap->mask) cairo_pattern_destroy(pixmap->mask);
+      pixmap->mask = (cairo_pattern_t *)g_value_get_pointer(value);
+      if(pixmap->mask) cairo_pattern_reference(pixmap->mask);
       break;
   }
 }
@@ -188,7 +188,7 @@ gtk_plot_pixmap_init (GtkPlotPixmap *dataset)
  * Return value: a new GtkWidget.
  */
 GtkWidget*
-gtk_plot_pixmap_new (GdkPixmap *pixmap, GdkBitmap *mask)
+gtk_plot_pixmap_new (cairo_surface_t *pixmap, cairo_pattern_t *mask)
 {
   GtkWidget *widget;
 
@@ -208,24 +208,24 @@ gtk_plot_pixmap_new (GdkPixmap *pixmap, GdkBitmap *mask)
  *
  */
 void
-gtk_plot_pixmap_construct(GtkPlotPixmap *data, GdkPixmap *pixmap, GdkBitmap *mask)
+gtk_plot_pixmap_construct(GtkPlotPixmap *data, cairo_surface_t *pixmap, cairo_pattern_t *mask)
 {
   data->pixmap = pixmap;
   data->mask = mask;
 
   if(pixmap)
-    gdk_pixmap_ref(pixmap);
+    cairo_surface_reference(pixmap);
   if(mask)
-    gdk_bitmap_ref(mask);
+    cairo_pattern_reference(mask);
 }
 
 static void
-gtk_plot_pixmap_destroy(GtkObject *object)
+gtk_plot_pixmap_destroy(GtkWidget *object)
 {
   GtkPlotPixmap *pixmap = GTK_PLOT_PIXMAP(object);
                                                                                 
-  if(pixmap->pixmap) gdk_pixmap_unref(pixmap->pixmap);
-  if(pixmap->mask) gdk_bitmap_unref(pixmap->mask);
+  if(pixmap->pixmap) cairo_surface_destroy(pixmap->pixmap);
+  if(pixmap->mask) cairo_pattern_destroy(pixmap->mask);
   pixmap->pixmap = NULL;
   pixmap->mask = NULL;
 }
@@ -236,9 +236,9 @@ gtk_plot_pixmap_clone(GtkPlotData *data, GtkPlotData *copy)
   GTK_PLOT_DATA_CLASS(parent_class)->clone(data, copy);
 
   GTK_PLOT_PIXMAP(copy)->pixmap = GTK_PLOT_PIXMAP(data)->pixmap;
-  gdk_pixmap_ref(GTK_PLOT_PIXMAP(data)->pixmap);
+  cairo_surface_reference(GTK_PLOT_PIXMAP(data)->pixmap);
   GTK_PLOT_PIXMAP(copy)->mask = GTK_PLOT_PIXMAP(data)->mask;
-  gdk_bitmap_ref(GTK_PLOT_PIXMAP(data)->mask);
+  cairo_pattern_reference(GTK_PLOT_PIXMAP(data)->mask);
 }
 
 static void
@@ -259,7 +259,8 @@ gtk_plot_pixmap_draw_symbol(GtkPlotData *data,
 
   scale_x = scale_y = data->plot->magnification;;
 
-  gdk_window_get_size(image->pixmap, &width, &height);
+  width = cairo_image_surface_get_width(image->pixmap);
+  height = cairo_image_surface_get_height(image->pixmap);
 
   width = roundint(scale_x * width);
   height = roundint(scale_y * height);
@@ -318,7 +319,8 @@ gtk_plot_pixmap_draw_legend(GtkPlotData *data, gint x, gint y)
   m = plot->magnification;
   legend = plot->legends_attr;
 
-  gdk_window_get_size(pixmap->pixmap, &width, &height);
+  width = cairo_image_surface_get_width(pixmap->pixmap);
+  height = cairo_image_surface_get_height(pixmap->pixmap);
   width = roundint(m * width);
   height = roundint(m * height);
 
@@ -386,7 +388,8 @@ gtk_plot_pixmap_get_legend_size(GtkPlotData *data, gint *width, gint *height)
   else
     legend.text = "";
 
-  gdk_window_get_size(pixmap->pixmap, &pwidth, &pheight);
+  pwidth = cairo_image_surface_get_width(pixmap->pixmap);
+  pheight = cairo_image_surface_get_height(pixmap->pixmap);
   pwidth = roundint(m * pwidth);
   pheight = roundint(m * pheight);
 
@@ -410,7 +413,7 @@ gtk_plot_pixmap_get_legend_size(GtkPlotData *data, gint *width, gint *height)
  *
  * Return value: (transfer none) the #GdkPixmap
  */
-GdkPixmap *
+cairo_surface_t *
 gtk_plot_pixmap_get_pixmap (GtkPlotPixmap *pixmap)
 {
   return(pixmap->pixmap);
@@ -424,7 +427,7 @@ gtk_plot_pixmap_get_pixmap (GtkPlotPixmap *pixmap)
  *
  * Return value: (transfer none) the #GdkBitmap
  */
-GdkBitmap *
+cairo_pattern_t *
 gtk_plot_pixmap_get_mask (GtkPlotPixmap *pixmap)
 {
   return(pixmap->mask);
