@@ -41,7 +41,7 @@
 
 static void gtk_plot_surface_class_init 	(GtkPlotSurfaceClass *klass);
 static void gtk_plot_surface_init 		(GtkPlotSurface *data);
-static void gtk_plot_surface_destroy 		(GtkObject *object);
+static void gtk_plot_surface_destroy 		(GtkWidget *object);
 static void gtk_plot_surface_get_property         (GObject      *object,
                                                  guint            prop_id,
                                                  GValue          *value,
@@ -66,8 +66,8 @@ static void gtk_plot_surface_draw_legend	(GtkPlotData *data,
 static void gtk_plot_surface_get_legend_size   (GtkPlotData *data,
                                                  gint *width, gint *height);
 static void gtk_plot_surface_draw_polygons 	(GtkPlotSurface *surface);
-static void gtk_plot_surface_lighting 		(GdkColor *a, 
-						 GdkColor *b, 
+static void gtk_plot_surface_lighting 		(GdkRGBA *a,
+						 GdkRGBA *b,
 						 gdouble normal,
 						 gdouble ambient);
 static void clear_polygons                      (GtkPlotSurface *surface);
@@ -142,14 +142,14 @@ gtk_plot_surface_get_type (void)
 static void
 gtk_plot_surface_class_init (GtkPlotSurfaceClass *klass)
 {
-  GtkObjectClass *object_class;
+  GtkWidgetClass *object_class;
   GtkPlotDataClass *data_class;
   GtkPlotSurfaceClass *surface_class;
   GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
 
   parent_class = g_type_class_ref (gtk_plot_data_get_type ());
 
-  object_class = (GtkObjectClass *) klass;
+  object_class = (GtkWidgetClass *) klass;
   data_class = (GtkPlotDataClass *) klass;
   surface_class = (GtkPlotSurfaceClass *) klass;
 
@@ -402,7 +402,7 @@ gtk_plot_surface_set_property (GObject      *object,
         data->mesh_line.line_width = g_value_get_double(value);
         break;
       case ARG_MESH_COLOR:
-        data->mesh_line.color = *((GdkColor *)g_value_get_pointer(value));
+        data->mesh_line.color = *((GdkRGBA *)g_value_get_pointer(value));
         break;
     }
 }
@@ -583,30 +583,21 @@ gtk_plot_surface_add_to_plot (GtkPlotData *data, GtkPlot *plot)
 static void
 gtk_plot_surface_init (GtkPlotSurface *dataset)
 {
-  GtkWidget *widget;
-  GdkColormap *colormap;
-  GdkColor color;
+  GdkRGBA color;
   GtkPlotArray *dim;
 
   gtk_widget_set_has_window(GTK_WIDGET(dataset), FALSE);
 
-  widget = GTK_WIDGET(dataset);
-  colormap = gtk_widget_get_colormap(widget);
-
-  gdk_color_parse("black", &color);
-  gdk_color_alloc(colormap, &color);
+  gdk_rgba_parse(&color, "black");
   dataset->grid_foreground = color;
 
-  gdk_color_parse("dark green", &color);
-  gdk_color_alloc(colormap, &color);
+  gdk_rgba_parse(&color, "dark green");
   dataset->grid_background = color;
 
-  gdk_color_parse("gray30", &color);
-  gdk_color_alloc(colormap, &color);
+  gdk_rgba_parse(&color, "gray30");
   dataset->shadow = color;
 
-  gdk_color_parse("blue", &color);
-  gdk_color_alloc(colormap, &color);
+  gdk_rgba_parse(&color, "blue");
   dataset->color = color;
 
   dataset->light.x = 0.;
@@ -691,21 +682,21 @@ gtk_plot_surface_construct_function(GtkPlotSurface *surface,
  *
  */
 void
-gtk_plot_surface_destroy(GtkObject *object) 
+gtk_plot_surface_destroy(GtkWidget *object)
 {
   GtkPlotSurface *surface;
  
   surface = GTK_PLOT_SURFACE(object);
 
   if(surface->dt){
-    gtk_object_destroy(GTK_OBJECT(surface->dt));
+    gtk_widget_destroy(GTK_WIDGET(surface->dt));
     surface->dt = NULL;
   }
 
   clear_polygons(surface);
 
-  if ( GTK_OBJECT_CLASS (parent_class)->destroy )
-    (* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+  if ( GTK_WIDGET_CLASS (parent_class)->destroy )
+    (* GTK_WIDGET_CLASS (parent_class)->destroy) (object);
 }
 
 static void
@@ -774,7 +765,7 @@ gtk_plot_surface_draw_private   (GtkPlotData *data)
   if(data->redraw_pending) gtk_plot_surface_update_range(data);
 
   gtk_plot_pc_gsave(plot->pc);
-  GTK_PLOT_SURFACE_CLASS(GTK_OBJECT_GET_CLASS(GTK_OBJECT(surface)))->draw_polygons(surface); 
+  GTK_PLOT_SURFACE_CLASS(GTK_WIDGET_GET_CLASS(GTK_WIDGET(surface)))->draw_polygons(surface);
   gtk_plot_pc_grestore(plot->pc);
 }
 
@@ -787,7 +778,7 @@ gtk_plot_surface_draw_polygons (GtkPlotSurface *surface)
   GtkPlotDTtriangle *triangle;
   gboolean visible = TRUE;
   GtkPlotVector side1, side2, light, normal;
-  GdkColor color, real_color;
+  GdkRGBA color, real_color;
   GtkPlotVector points[3];
   gdouble factor, norm;
   GList *list;
@@ -1018,7 +1009,7 @@ gtk_plot_surface_draw_legend(GtkPlotData *data, gint x, gint y)
       step = (data->gradient->ticks.max - data->gradient->ticks.min) / 10;
       lstep = roundint(plot->legends_line_width * m / 10.);
       for(level = data->gradient->ticks.min; level < data->gradient->ticks.max; level += step){
-        GdkColor color;
+        GdkRGBA color;
         gtk_plot_data_get_gradient_level(data, level, &color);
         gtk_plot_pc_set_color(plot->pc, &color);
   
@@ -1041,7 +1032,7 @@ gtk_plot_surface_draw_legend(GtkPlotData *data, gint x, gint y)
 }
 
 static void
-gtk_plot_surface_lighting (GdkColor *a, GdkColor *b, 
+gtk_plot_surface_lighting (GdkRGBA *a, GdkRGBA *b,
                            gdouble normal, gdouble ambient)
 {
   gdouble red, green, blue;
@@ -1134,10 +1125,6 @@ hsv_to_rgb (gdouble  h, gdouble  s, gdouble  v,
           break;
       }
     }
-
-  *r *= 65535.;
-  *g *= 65535.;
-  *b *= 65535.;
 }
 
 static void
@@ -1146,10 +1133,6 @@ rgb_to_hsv (gdouble  r, gdouble  g, gdouble  b,
 {
   double max, min, delta;
 
-  r /= 65535.;
-  g /= 65535.;
-  b /= 65535.;
-
   max = r;
   if (g > max)
     max = g;
@@ -1209,7 +1192,7 @@ rgb_to_hsv (gdouble  r, gdouble  g, gdouble  b,
  */
 void            
 gtk_plot_surface_set_color      (GtkPlotSurface *data,
-                                 GdkColor *color)
+                                 GdkRGBA *color)
 {
   data->color = *color;
 }
@@ -1223,7 +1206,7 @@ gtk_plot_surface_set_color      (GtkPlotSurface *data,
  */
 void            
 gtk_plot_surface_set_shadow     (GtkPlotSurface *data,
-                                 GdkColor *color)
+                                 GdkRGBA *color)
 {
   data->shadow = *color;
 }
@@ -1237,7 +1220,7 @@ gtk_plot_surface_set_shadow     (GtkPlotSurface *data,
  */
 void            
 gtk_plot_surface_set_grid_foreground    (GtkPlotSurface *data,
-                                         GdkColor *foreground)
+                                         GdkRGBA *foreground)
 {
   data->grid_foreground = *foreground;
 }
@@ -1251,7 +1234,7 @@ gtk_plot_surface_set_grid_foreground    (GtkPlotSurface *data,
  */
 void            
 gtk_plot_surface_set_grid_background    (GtkPlotSurface *data,
-                                         GdkColor *background)
+                                         GdkRGBA *background)
 {
   data->grid_background = *background;
 }
@@ -1906,7 +1889,7 @@ gtk_plot_surface_real_build_mesh(GtkPlotSurface *surface)
   }
   gtk_plot_dt_triangulate(surface->dt);
 
-  GTK_PLOT_SURFACE_CLASS(GTK_OBJECT_GET_CLASS(GTK_OBJECT(surface)))->build_polygons(surface); 
+  GTK_PLOT_SURFACE_CLASS(GTK_WIDGET_GET_CLASS(GTK_WIDGET(surface)))->build_polygons(surface);
 
   gtk_plot_surface_recalc_nodes(surface);
   surface->recalc_dt = FALSE;
@@ -1995,7 +1978,7 @@ gtk_plot_surface_recalc_nodes(GtkPlotSurface *surface)
     list = list->next;
   };
 
-  GTK_PLOT_SURFACE_CLASS(GTK_OBJECT_GET_CLASS(GTK_OBJECT(surface)))->sort_polygons(surface); 
+  GTK_PLOT_SURFACE_CLASS(GTK_WIDGET_GET_CLASS(GTK_WIDGET(surface)))->sort_polygons(surface);
   
 }
 
